@@ -413,10 +413,15 @@ def find_or_create_project(api_url, project, create_new=False):
     if not resp.ok:
         raise OSError('nuclio API call failed')
     for k, v in resp.json().items():
-        if v['spec'].get('displayName') == project:
+        if v['metadata'].get('name') == project:
             return k
 
-        if k == project:
+        # displayName is deprecated
+        # older version of nuclio might still rely on it
+        elif v['spec'].get('displayName') == project:
+            return k
+
+        elif k == project:
             return k
 
     if not create_new:
@@ -424,7 +429,7 @@ def find_or_create_project(api_url, project, create_new=False):
 
     # create a new project
     headers = {'Content-Type': 'application/json'}
-    config = {"metadata": {"name": project}, "spec": {"displayName": project}}
+    config = {"metadata": {"name": project}, "spec": {}}
 
     try:
         resp = requests.post(apipath, json=config,
